@@ -5,18 +5,18 @@
 
 using namespace std;
 
-owner::owner( std::string package_, std::string glob_ )
+owner::owner( std::string package_, std::string path_ )
 {
         package = std::move(package_);
-        glob = std::move(glob_);
+        path = std::move(path_);
 }
 
 bool operator==(owner const& l, owner const &r)
 {
-    return l.glob == r.glob;
+    return l.path == r.path;
 }
 
 bool operator<(owner const& l, owner const &r)
 {
-    return l.glob < r.glob;
+    return l.path < r.path;
 }
